<?php	
	
	/**********************************************
	CUSTOM POST TYPE: GALLERY
	***********************************************/	

	add_action( 'init', 'gallery_post_type' );
	function gallery_post_type() { 

		if(get_option('fas_gallery_cpt')!="") { $gallery_name = get_option('fas_gallery_cpt'); } else { $gallery_name = "Gallery"; }
		if(get_option('fas_gallery_cpt_slug')!="") { $gallery_slug = get_option('fas_gallery_cpt_slug'); } else { $gallery_slug = "gallery-item"; }
		if(get_option('fas_gallery_add')!="") { $gallery_add = get_option('fas_gallery_add'); } else { $gallery_add = "Add Gallery"; }
		if(get_option('fas_gallery_edit')!="") { $gallery_edit = get_option('fas_gallery_edit'); } else { $gallery_edit = "Edit Gallery"; }
		
		register_post_type( 'gallery',
			array(
				'labels' => array(
					'name' => $gallery_name,
					'singular_name' => $gallery_name,
					'add_new_item' => $gallery_add,
					'edit_item' => $gallery_edit,
				),
				'public' => true,
				'has_archive' => true,	
				'publicly_queryable' => true,
			    'show_ui' => true, 
			    'show_in_menu' => true, 
			    'query_var' => true,	
			    'rewrite' => array( 'slug' => $gallery_slug, 'with_front' => TRUE ),
			    'supports' => array('title', 'editor', 'author', 'thumbnail', 'page-attributes'),
				'menu_icon' => get_template_directory_uri() . '/includes/custom/img/gallery.png'		
			)
		);
		flush_rewrite_rules();
	}
	
	/*META*/
	function gallery_meta() {
		global $post;

		$bgimage = get_post_meta($post->ID, 'bgimage', TRUE);
		$exclude = get_post_meta($post->ID, 'exclude', TRUE);
		$bgslide = get_post_meta($post->ID, 'bgslide', TRUE);
		$subtitle = get_post_meta($post->ID, 'subtitle', TRUE);
		$video = get_post_meta($post->ID, 'video', TRUE);

		?>
			<div class="mabuc-form-wrap">	
				<table>
					<tr>
						<td style="width:10%;"><label for="exclude"><?php _e( 'Exclude', ENGINE_THEME_NAME ); ?></label></td>
						<td>
							<input name="exclude" type="checkbox" id="exclude" <?php if( $exclude == true ) { ?>checked="checked"<?php } ?> />
							<span class="desc"><?php _e( 'Check this if you want to exclude this album in the list', ENGINE_THEME_NAME ); ?></span>
						</td>
					</tr>
					<tr>
						<td><label for="bgslide"><?php _e( 'Slider', ENGINE_THEME_NAME ); ?></label> </td>
						<td>
							<input name="bgslide" type="checkbox" id="bgslide" <?php if( $bgslide == true ) { ?>checked="checked"<?php } ?> />
							<span class="desc"><?php _e( 'Check this if you want to include this album in background slider', ENGINE_THEME_NAME ); ?></span>
						</td>
					</tr>
					<tr>
						<td><label for="subtitle"><?php _e( 'Subtitle', ENGINE_THEME_NAME ); ?></label> </td>
						<td>
							<input name="subtitle" type="text" id="subtitle" value="<?php echo $subtitle; ?>" /> <br>
							<span class="desc"><?php _e( 'Add your post subtitle here', ENGINE_THEME_NAME ); ?></span>
						</td>
					</tr>
					<tr>
						<td><label for="video"><?php _e( 'Video', ENGINE_THEME_NAME ); ?></label> </td>
						<td>
							<input name="video" type="text" id="video" value="<?php echo $video; ?>" /> <br> 
							<span class="desc"><?php _e( 'Add your video url here (ex: http://player.vimeo.com/video/21942776 and http://www.youtube.com/v/f2XQ97XHjVw)', ENGINE_THEME_NAME ); ?></span>
						</td>
					</tr>
					<tr>
						<td><label for="bgimage"><?php _e( 'Background', 'source_lang' ); ?></label></td>
						<td>	
							<input name="bgimage" type="text" id="bgimage" value="<?php echo $bgimage; ?>" /> <input id="upload_image_button_fas_bgimage" type="button" value="Upload" class="button-secondary" /><br>
							<span class="desc"><?php _e( 'Add your background image here', ENGINE_THEME_NAME ); ?></span>
						</td>
					</tr>
				</table>					
			</div>		
		<?php
	}

	
	/*TAXONOMIES*/
	add_action( 'init', 'gallery_taxonomies', 0 );
	function gallery_taxonomies() {
		if(get_option('fas_gallery_tax_slug')!="") { $gallery_tax_slug = get_option('fas_gallery_tax_slug'); } else { $gallery_tax_slug = "gallery-category"; }

		register_taxonomy( 'gallery_categories', 'gallery', array( 'hierarchical' => true, 'label' => 'Categories', 'query_var' => true, 'rewrite' => array('slug' => $gallery_tax_slug) ) );
	}

	/*CUSTOM COLUMNS*/
	add_filter( 'manage_edit-gallery_columns', 'edit_gallery_columns' ) ;
	function edit_gallery_columns( $columns ) {
		$columns = array(
			'cb' => '<input type="checkbox" />',
			'title' => __( 'Name', ENGINE_THEME_NAME ),						
			'category' => __( 'Categories', ENGINE_THEME_NAME ),
			'author' => __( 'Author', ENGINE_THEME_NAME ),
			'thumbnail' => __( 'Thumbnail', ENGINE_THEME_NAME ),
			'date' => __( 'Date', ENGINE_THEME_NAME )
		);
		return $columns;
	}

	/*CUSTOM COLUMNS LIST*/
	add_action( 'manage_gallery_posts_custom_column', 'manage_gallery_columns', 10, 2 );
	function manage_gallery_columns( $column, $post_id ) {
		global $post;

		switch($column) {
			case 'url' :
				$url = get_post_meta( $post_id, 'url', true );
				if ( empty( $url ) )
					echo __( 'No URL', ENGINE_THEME_NAME );
				else
					?><a href="<?php printf( __( '%s', ENGINE_THEME_NAME ), $url ); ?>" target="_blank"><?php printf( __( '%s', ENGINE_THEME_NAME ), $url ); ?></a><?php
			break;
			
			case 'category' :
				$terms = get_the_terms( $post_id, 'gallery_categories' );
				if ( !empty( $terms ) ) {
					$out = array();
					foreach ( $terms as $term ) {
						$out[] = sprintf( '<a href="%s">%s</a>',
							esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'gallery_categories' => $term->slug ), 'edit.php' ) ),
							esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'gallery_categories', 'display' ) )
						);
					}
					echo join( ', ', $out );
				}				
				else { __( 'No Categories', ENGINE_THEME_NAME ); }
			break;

			case 'thumbnail' : 
      			echo the_post_thumbnail( array(35,35) );
      		break;
			
			default :
			break;
		}
	}

	
	/**********************************************
	SAVE & UPDATE CUSTOM FIELDS
	***********************************************/
	
	add_action( 'add_meta_boxes', 'custom_posts_box' );
	function custom_posts_box(){
		add_meta_box("gallery_meta", "Gallery Options", "gallery_meta", "gallery", "normal", "low");
	}
	
	add_action('save_post', 'custom_posts_save');
	function custom_posts_save( $post_id ){
		
		if ((defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) || (defined('DOING_AJAX') && DOING_AJAX)) return;
		if ( 'page' == isset($_POST['post_type']) ) { if ( !current_user_can( 'edit_page', $post_id ) ) return;
		} else { if ( !current_user_can( 'edit_post', $post_id ) ) return; }

		update_post_meta($post_id, "bgslide", @$_POST["bgslide"]);	
		update_post_meta($post_id, "bgimage", @$_POST["bgimage"]);	
		update_post_meta($post_id, "exclude", @$_POST["exclude"]);	
		update_post_meta($post_id, "subtitle", @$_POST["subtitle"]);	
		update_post_meta($post_id, "video", @$_POST["video"]);		
	}	
?>